# Code of Conduct

## Our Pledge

We are committed to making participation in this project a harassment-free experience for everyone, regardless of age, body size, disability, ethnicity, gender identity and expression, level of experience, nationality, personal appearance, race, religion, or sexual identity and orientation.

## Our Standards

Examples of behavior that contributes to a positive environment include:

- Demonstrating empathy and respect.
- Giving and accepting constructive feedback.
- Focusing on what is best for the project and community.
- Showing courtesy and professionalism in public and private interactions.

Examples of unacceptable behavior include:

- Harassment, intimidation, or discrimination.
- Trolling, insulting, or derogatory comments.
- Public or private harassment.
- Publishing others' private information without explicit permission.
- Other conduct which could reasonably be considered inappropriate in a professional setting.

## Enforcement Responsibilities

Project maintainers are responsible for clarifying and enforcing this code of conduct and may take appropriate corrective action in response to unacceptable behavior.

## Scope

This code of conduct applies within project spaces and in public spaces when an individual is officially representing the project.

## Reporting

Report conduct issues to `hello@super-agentic.ai`. All reports will be reviewed and investigated promptly and fairly.

## Enforcement

Maintainers may remove, edit, or reject comments, commits, code, issues, and other contributions that are not aligned with this code of conduct.

This document is adapted from the Contributor Covenant, version 2.1.
